pychemia.crystal.tests package
==============================

.. automodule:: pychemia.crystal.tests
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.crystal.tests.test_doctest module
------------------------------------------

.. automodule:: pychemia.crystal.tests.test_doctest
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.crystal.tests.test_kpoints module
------------------------------------------

.. automodule:: pychemia.crystal.tests.test_kpoints
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.crystal.tests.test_symmetry module
-------------------------------------------

.. automodule:: pychemia.crystal.tests.test_symmetry
    :members:
    :undoc-members:
    :show-inheritance:


